@@ -1,6 +1,5 @@
 import boto3
 import json
-from abc import ABC, abstractclassmethod
 from signal import signal, SIGINT, SIGTERM
 from django.conf import settings
 
@@ -16,32 +15,11 @@ class SignalHandler:
         self.received_signal = True
 
 
-class ExchangeBase(ABC):
-
-    @abstractclassmethod
-    def get_exchange_methods():
-        pass
-
-
-class ConsumerBase(ABC):
-
-    @abstractclassmethod
-    def __init__(self, exchanges):
-        pass
-
-    @abstractclassmethod
-    def consume(cls):
-        pass
-
-
-class Sqs(ConsumerBase):
+class Sqs:
 
     def __init__(self, exchanges):
         self.exchanges = exchanges
 
-    def consumer_fn():
-        pass
-
     def consume(self):
         sqs_client_options = {
             'region_name': settings.AWS_REGION_NAME,
@@ -59,14 +37,3 @@ class Sqs(ConsumerBase):
                 exchange_fn = self.exchanges[body.get('Subject')]
                 exchange_fn(body.get('Message'))
                 message.delete()
-
-
-class ConsumerFactory:
-
-    @staticmethod
-    def get_consumer(consumer_name, exchanges):
-        CONSUMERS = {
-            'SQS': Sqs
-        }
-        Consumer = CONSUMERS[consumer_name]
-        return Consumer(exchanges=exchanges)
